@@ -1,9 +1,11 @@
 """Cleaning dirty input text."""
+from typing import Iterable, Optional
+
 import re
 
 import requests
 from bs4 import BeautifulSoup
-from cleaning_utils import clear_stop_char, replace_arabic_char
+from cleaning_utils import clear_stop_char, clear_stop_words, replace_arabic_char
 from polyglot.detect import Detector
 
 
@@ -37,11 +39,17 @@ def fetch_page_text(url: str = "", webpage: str = "") -> str:
     return whole_page
 
 
-def cleaner(dirty_text: str) -> str:
+def cleaner(
+    dirty_text: str,
+    replace_stop: bool = False,
+    stop_list: Optional[Iterable[str]] = None,
+) -> str:
     """Main function for cleaning.
 
     Args:
         dirty_text: Input dirty text
+        replace_stop: Whether to replace stop words or not
+        stop_list: list of stop words
 
     Returns:
         Final text ready for integration in NLP algorithms.
@@ -62,6 +70,11 @@ def cleaner(dirty_text: str) -> str:
         replace_char=".",
     )
 
+    if replace_stop:
+        processed_text = clear_stop_words(
+            text=processed_text, stop_list=stop_list, replace_char="."  # type: ignore
+        )
+
     # ------------------- Trimmer phase -------------------
     processed_text = processed_text.replace("\t", " ").replace("\n", " ").strip()
     processed_text = processed_text.replace("\u200c", " ")  # Nim-fasele
